#ifndef DEFAULTS_H
#define DEFAULTS_H

#define LISTEN_PORT             6789    /* Default listen port  */
#define LISTEN_PORT_STRING      "6789"  /* Default listen port as string */
#define DEFAULT_PORT            LISTEN_PORT
#define MAX_SIMUL_CONNECT       30      /* Default upper limit on simultaneous connections      */
#define TIMEOUT                 10      /* 10 seconds time out for client to send conninit structure */
#define PRIVATE_KEY_FILE        "Server.prv"
#define PUBLIC_KEY_FILE         "Server.pub"
#define RANDOM_SEED_FILE        "/dev/urandom"	/* Default seed file, overridable with -r	*/
#define AESOPD_CONF_FILE	"aesopd.conf"
#define GLOBAL_AESOPD_CONF_FILE "/etc/"AESOPD_CONF_FILE
#define AESOPTUNNEL_CONF_FILE	"aesoptunnel.conf"
#define GLOBAL_AESOPTUNNEL_CONF_FILE "/etc/"AESOPTUNNEL_CONF_FILE
#endif
